==> eiffelstudio-18.11.10.2592.tar: F_code/C42/li2074.c <==
/*
 * Code for class LINEAR [POINTER]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "li2074.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LINEAR}.has */
EIF_BOOLEAN F694_8855 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("has", 693, Current, 0, 1, 8927);
	RTGC;
	RTHOOK(1);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R7655[dtype-789])(Current);
	RTHOOK(2);
	if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R7654[dtype-685])(Current)) {
		RTHOOK(3);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7661[dtype-685])(Current, (EIF_REFERENCE) &arg1);
	}
	RTHOOK(4);
	Result = F694_8861(Current);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {LINEAR}.index_of */
EIF_INTEGER_32 F694_8856 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("index_of", 693, Current, 2, 2, 8928);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current + O7547[dtype-658]) && EIF_TRUE)) {
		RTHOOK(2);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R7655[dtype-789])(Current);
		RTHOOK(3);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			RTHOOK(4);
			tb1 = '\01';
			if (!F694_8861(Current)) {
				tb1 = (EIF_BOOLEAN)(loc1 == arg2);
			}
			if (tb1) break;
			RTHOOK(5);
			if ((F1153_10771(Current) == arg1)) {
				RTHOOK(6);
				loc1++;
			}
			RTHOOK(7);
			F1153_10799(Current);
			RTHOOK(8);
			loc2++;
		}
	} else {
		RTHOOK(9);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R7655[dtype-789])(Current);
		RTHOOK(10);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			RTHOOK(11);
			tb2 = '\01';
			if (!F694_8861(Current)) {
				tb2 = (EIF_BOOLEAN)(loc1 == arg2);
			}
			if (tb2) break;
			RTHOOK(12);
			if ((EIF_BOOLEAN)(F1153_10771(Current) == arg1)) {
				RTHOOK(13);
				loc1++;
			}
			RTHOOK(14);
			F1153_10799(Current);
			RTHOOK(15);
			loc2++;
		}
	}
	RTHOOK(16);
	if ((EIF_BOOLEAN)(loc1 == arg2)) {
		RTHOOK(17);
		RTHOOK(18);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	}
	RTHOOK(20);
	RTLE;
	RTEE;
	return (EIF_INTEGER_32) 0;
}

/* {LINEAR}.search */
void F694_8857 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("search", 693, Current, 0, 1, 8929);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current + O7547[Dtype(Current)-658])) {
		for (;;) {
			RTHOOK(2);
			tb1 = '\01';
			if (!F694_8861(Current)) {
				tb1 = (arg1 == F1153_10771(Current));
			}
			if (tb1) break;
			RTHOOK(3);
			F1153_10799(Current);
		}
	} else {
		for (;;) {
			RTHOOK(4);
			tb2 = '\01';
			if (!F694_8861(Current)) {
				tb2 = (EIF_BOOLEAN)(arg1 == F1153_10771(Current));
			}
			if (tb2) break;
			RTHOOK(5);
			F1153_10799(Current);
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {LINEAR}.item_for_iteration */
EIF_POINTER F694_8860 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("item_for_iteration", 693, Current, 0, 0, 8931);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_POINTER) F1153_10771(Current);
}

/* {LINEAR}.exhausted */
EIF_BOOLEAN F694_8861 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("exhausted", 693, Current, 0, 0, 8932);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R7654[Dtype(Current)-685])(Current);
}

/* {LINEAR}.off */
EIF_BOOLEAN F694_8863 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("off", 693, Current, 0, 0, 8933);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	if (!F799_8929(Current)) {
		Result = F935_9173(Current);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {LINEAR}.do_all */
void F694_8866 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc3);
	RTLR(1,Current);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("do_all", 693, Current, 3, 1, 8921);
	RTGC;
	RTHOOK(1);
	loc3 = Current;
	{
		static EIF_TYPE_INDEX typarr0[] = {771,0,0,0xFFFF};
		EIF_TYPE typres0;
		{
			EIF_TYPE l_type;
			l_type = eif_final_id(Y7499,Y7499_gen_type,dftype,637);
			typarr0[1] = l_type.annotations | 0xFF00;
			typarr0[2] = l_type.id;
		}
		
		typres0 = eif_compound_id(dftype, typarr0);
		loc3 = RTRV(typres0,loc3);
	}
	if (EIF_TEST(loc3)) {
		RTHOOK(2);
		loc2 = (EIF_REFERENCE) loc3;
		RTHOOK(3);
		loc1 = F1153_10777(loc3);
	}
	RTHOOK(4);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R7655[Dtype(Current)-789])(Current);
	for (;;) {
		RTHOOK(5);
		if (F935_9173(Current)) break;
		RTHOOK(6);
		tp1 = F1153_10771(Current);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_POINTER)) *(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_), tp1);
		;
		RTHOOK(7);
		F1153_10799(Current);
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 != NULL) && (EIF_BOOLEAN)(loc1 != NULL))) {
		RTHOOK(9);
		F1153_10802(RTCW(loc2), loc1);
	}
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {LINEAR}.linear_representation */
EIF_REFERENCE F694_8870 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("linear_representation", 693, Current, 0, 0, 8925);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) Current;
}

void EIF_Minit2074 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C42/li2074.c <==
/*
 * Code for class LINEAR [POINTER]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "li2074.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {LINEAR}.has */
EIF_BOOLEAN F725_9590 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("has", 724, Current, 0, 1, 9644);
	RTGC;
	RTHOOK(1);
	F1167_10518(Current);
	RTHOOK(2);
	if ((EIF_BOOLEAN) !F960_9878(Current)) {
		RTHOOK(3);
		F1167_10524(Current, arg1);
	}
	RTHOOK(4);
	Result = F725_9596(Current);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {LINEAR}.index_of */
EIF_INTEGER_32 F725_9591 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("index_of", 724, Current, 2, 2, 9645);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) && EIF_TRUE)) {
		RTHOOK(2);
		F1167_10518(Current);
		RTHOOK(3);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			RTHOOK(4);
			tb1 = '\01';
			if (!F725_9596(Current)) {
				tb1 = (EIF_BOOLEAN)(loc1 == arg2);
			}
			if (tb1) break;
			RTHOOK(5);
			if ((F1167_10492(Current) == arg1)) {
				RTHOOK(6);
				loc1++;
			}
			RTHOOK(7);
			F1167_10520(Current);
			RTHOOK(8);
			loc2++;
		}
	} else {
		RTHOOK(9);
		F1167_10518(Current);
		RTHOOK(10);
		loc2 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
		for (;;) {
			RTHOOK(11);
			tb2 = '\01';
			if (!F725_9596(Current)) {
				tb2 = (EIF_BOOLEAN)(loc1 == arg2);
			}
			if (tb2) break;
			RTHOOK(12);
			if ((EIF_BOOLEAN)(F1167_10492(Current) == arg1)) {
				RTHOOK(13);
				loc1++;
			}
			RTHOOK(14);
			F1167_10520(Current);
			RTHOOK(15);
			loc2++;
		}
	}
	RTHOOK(16);
	if ((EIF_BOOLEAN)(loc1 == arg2)) {
		RTHOOK(17);
		RTHOOK(18);
		RTLE;
		RTEE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L));
	}
	RTHOOK(20);
	RTLE;
	RTEE;
	return (EIF_INTEGER_32) 0;
}

/* {LINEAR}.search */
void F725_9592 (EIF_REFERENCE Current, EIF_POINTER arg1)
{
	GTCX
	RTEX;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("search", 724, Current, 0, 1, 9646);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
		for (;;) {
			RTHOOK(2);
			tb1 = '\01';
			if (!F725_9596(Current)) {
				tb1 = (arg1 == F1167_10492(Current));
			}
			if (tb1) break;
			RTHOOK(3);
			F1167_10520(Current);
		}
	} else {
		for (;;) {
			RTHOOK(4);
			tb2 = '\01';
			if (!F725_9596(Current)) {
				tb2 = (EIF_BOOLEAN)(arg1 == F1167_10492(Current));
			}
			if (tb2) break;
			RTHOOK(5);
			F1167_10520(Current);
		}
	}
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {LINEAR}.item_for_iteration */
EIF_POINTER F725_9595 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("item_for_iteration", 724, Current, 0, 0, 9648);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_POINTER) F1167_10492(Current);
}

/* {LINEAR}.exhausted */
EIF_BOOLEAN F725_9596 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("exhausted", 724, Current, 0, 0, 9649);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_BOOLEAN) F960_9878(Current);
}

/* {LINEAR}.off */
EIF_BOOLEAN F725_9598 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("off", 724, Current, 0, 0, 9650);
	RTGC;
	RTHOOK(1);
	Result = '\01';
	if (!F847_9666(Current)) {
		Result = F984_9902(Current);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {LINEAR}.do_all */
void F725_9601 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_POINTER tp1;
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc3);
	RTLR(1,Current);
	RTLR(2,loc2);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLIU(5);
	
	RTEAA("do_all", 724, Current, 3, 1, 9652);
	RTGC;
	RTHOOK(1);
	loc3 = Current;
	{
		static EIF_TYPE_INDEX typarr0[] = {819,0,0,0xFFFF};
		EIF_TYPE typres0;
		{
			EIF_TYPE l_type;
			l_type = eif_final_id(Y8170,Y8170_gen_type,dftype,670);
			typarr0[1] = l_type.annotations | 0xFF00;
			typarr0[2] = l_type.id;
		}
		
		typres0 = eif_compound_id(dftype, typarr0);
		loc3 = RTRV(typres0,loc3);
	}
	if (EIF_TEST(loc3)) {
		RTHOOK(2);
		loc2 = (EIF_REFERENCE) loc3;
		RTHOOK(3);
		loc1 = F1167_10498(loc3);
	}
	RTHOOK(4);
	F1167_10518(Current);
	for (;;) {
		RTHOOK(5);
		if (F984_9902(Current)) break;
		RTHOOK(6);
		tp1 = F1167_10492(Current);
		(FUNCTION_CAST(void, (EIF_POINTER, EIF_REFERENCE, EIF_POINTER)) *(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_), tp1);
		RTHOOK(7);
		F1167_10520(Current);
	}
	RTHOOK(8);
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc2 != NULL) && (EIF_BOOLEAN)(loc1 != NULL))) {
		RTHOOK(9);
		F1167_10523(RTCW(loc2), loc1);
	}
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {LINEAR}.linear_representation */
EIF_REFERENCE F725_9605 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	
	
	RTEAA("linear_representation", 724, Current, 0, 0, 9656);
	RTHOOK(1);
	RTHOOK(2);
	RTEE;
	return (EIF_REFERENCE) Current;
}

void EIF_Minit2074 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
